# provis - A python based PROtein VISualization toolkit

FOR CHARLOTTE AND MOJMIR:
=================================================
If you pull the repo on linux it should already have all the binaries in the provis/binaries folder.

You can play around with the main.py file to see the capabilities of provis. 

=================================================

Welcome to the repository of Provis - a python based protein visualization library.

The easiest way to install is with ``` pip install provis ```, but the library has a few dependencies that have to be installed seperately.
Please visit the [documentation]() for [installation instructions]().

